-- Title: iLvLr
-- Author: JerichoHM
-- Version: 1.0.230
-- Desc: iLvL identifier

-- GetItemInfo
-- Frame/CreateFontString
-- FontString
-- UNIT_INVENTORY_CHANGED

--Version Information
local Title = "iLvLr"
local Core = "1"
local Revision = "0"
local Build = "230"

local frameDB = {CharacterHeadSlot,
					CharacterNeckSlot,
					CharacterShoulderSlot,
					CharacterBackSlot,
					CharacterChestSlot,
					CharacterWristSlot,
					CharacterShirtSlot,
					CharacterTabardSlot,
					CharacterMainHandSlot,
					CharacterSecondaryHandSlot,
					CharacterRangedSlot,
					CharacterHandsSlot,
					CharacterWaistSlot,
					CharacterLegsSlot,
					CharacterFeetSlot,
					CharacterFinger0Slot,
					CharacterFinger1Slot,
					CharacterTrinket0Slot,
					CharacterTrinket1Slot
				}

local slotDB = {"HeadSlot",
					"NeckSlot",
					"ShoulderSlot",
					"BackSlot",
					"ChestSlot",
					"WristSlot",
					"ShirtSlot",
					"TabardSlot",
					"MainHandSlot",
					"SecondaryHandSlot",
					"RangedSlot",
					"HandsSlot",
					"WaistSlot",
					"LegsSlot",
					"FeetSlot",
					"Finger0Slot",
					"Finger1Slot",
					"Trinket0Slot",
					"Trinket1Slot"
				}

local iLow, iHigh, iEqAvg, iAvg
				
local iQualityFrames = {}
local iDuraFrames = {}
				
function iLvLrMain()
	iLvLrFrame = CreateFrame("Frame", "iLvLrFrame", UIParent)

	iLvLrFrame:RegisterEvent("ADDON_LOADED")
	iLvLrFrame:RegisterEvent("UNIT_INVENTORY_CHANGED")
	iLvLrFrame:RegisterEvent("UPDATE_INVENTORY_DURABILITY")
	iLvLrFrame:SetScript("OnEvent", iLvLrOnEvent)
end

function iLvLrOnLoad()
	iEqAvg, iAvg = GetAverageItemLevel()
	
	for k ,v in pairs(slotDB) do
		local iLevel = fetchIlvl(v)
		if iLevel then			
			makeText(frameDB[k])
			makeQuality(frameDB[k], v)
			if v == "ShirtSlot" or v == "TabardSlot" then
				frameDB[k].text:SetFormattedText("", iLevel)
			else
				if iLevel <= (floor(iEqAvg) - 10) then
					frameDB[k].text:SetFormattedText("|cFFFF0000%i", iLevel)
				elseif iLevel >= (floor(iEqAvg) +10) then
					frameDB[k].text:SetFormattedText("|cFF00FF00%i", iLevel)
				else
					frameDB[k].text:SetFormattedText("|cFFFFFFFF%i", iLevel)
				end
				makeDurability(frameDB[k], v)
			end
		end
	end
end

function iLvLrOnUpdate()
	iEqAvg, iAvg = GetAverageItemLevel()
	
	for k ,v in pairs(slotDB) do
		local iLevel = fetchIlvl(v)
		if iLevel then
			if not frameDB[k].text then
				makeText(frameDB[k])
			end
			makeQuality(frameDB[k], v)
			if v == "ShirtSlot" or v == "TabardSlot" then
				frameDB[k].text:SetFormattedText("", iLevel)
			else
				if iLevel <= (floor(iEqAvg) - 10) then
					frameDB[k].text:SetFormattedText("|cFFFF0000%i", iLevel)
				elseif iLevel >= (floor(iEqAvg) + 10) then
					frameDB[k].text:SetFormattedText("|cFF00FF00%i", iLevel)
				else
					frameDB[k].text:SetFormattedText("|cFFFFFFFF%i", iLevel)
				end
				makeDurability(frameDB[k], v)
			end
		else
			if frameDB[k].text then
				frameDB[k].text:SetFormattedText("")
			end
			if iQualityFrames[v] then
				iQualityFrames[v]:Hide()
			end
			if iDuraFrames[v] then
				iDuraFrames[v]:Hide()
			end
		end
	end
end

function iLvLrOnEvent(self, event, arg1)
	if event == "ADDON_LOADED" and arg1 == "iLvLr" then
		iLvLrOnLoad()
	elseif event == "UNIT_INVENTORY_CHANGED" or event == "UPDATE_INVENTORY_DURABILITY" then
		iLvLrOnUpdate()
	end
end

function fetchIlvl(slotName)
	local slotId, texture, checkRelic = GetInventorySlotInfo(slotName)
	local itemId = GetInventoryItemID("player", slotId)
	if itemId then
		local name, link, quality, iLevel, reqLevel, class, subclass, maxStack, equipSlot, texture, vendorPrice = GetItemInfo(itemId)
		return(iLevel)
	end
end

function fetchQuality(slotName)
	local slotId, texture, checkRelic = GetInventorySlotInfo(slotName)
	local itemId = GetInventoryItemID("player", slotId)
	if itemId then
		local name, link, quality, iLevel, reqLevel, class, subclass, maxStack, equipSlot, texture, vendorPrice = GetItemInfo(itemId)
		local r, g, b, hex = GetItemQualityColor(quality)
		return r, g, b
	end
end

function fetchDura(slotName)
	local slotId, texture, checkRelic = GetInventorySlotInfo(slotName)
	if slotId then
		local itemDurability, itemMaxDurability = GetInventoryItemDurability(slotId)
		if itemDurability then
			return itemDurability, itemMaxDurability
		end
	end
end

function makeText(frame)
	local ilvlText = frame:CreateFontString(nil, "ARTWORK")
	isValid = ilvlText:SetFont("Fonts\\FRIZQT__.TTF", 10)
	
	if frame == CharacterHeadSlot or frame == CharacterNeckSlot or frame == CharacterShoulderSlot or frame == CharacterBackSlot or frame == CharacterChestSlot or frame == CharacterWristSlot or frame == CharacterShirtSlot or frame == CharacterTabardSlot then
		ilvlText:SetPoint("CENTER", frame, "CENTER", 42, 0)
	elseif frame == CharacterHandsSlot or frame == CharacterWaistSlot or frame == CharacterLegsSlot or frame == CharacterFeetSlot or frame == CharacterFinger0Slot or frame == CharacterFinger1Slot or frame == CharacterTrinket0Slot or frame == CharacterTrinket1Slot then
		ilvlText:SetPoint("CENTER", frame, "CENTER", -42, 0)
	elseif frame == CharacterMainHandSlot or frame == CharacterSecondaryHandSlot or frame == CharacterRangedSlot then
		ilvlText:SetPoint("CENTER", frame, "CENTER", 0, 42)
	end
	
	frame.text = ilvlText
end

function makeQuality(frame, slot)
	local iQuality = iQualityFrames[slot]
	if not iQuality then
		iQuality = CreateFrame("Frame", nil, frame)
		iQuality:SetPoint("CENTER", frame, "CENTER", 0, 0)
		iQuality:SetSize(frame:GetWidth(), frame:GetHeight())
		iQuality:SetBackdrop({bgFile = nil, edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border.blp", tile = true, tileSize = 32, edgeSize = 16, insets = {left = 0, right = 0, top = 0, bottom = 0}})
		
		local r, g, b = fetchQuality(slot)
		iQuality:SetBackdropBorderColor(r, g, b, 1.0)
		
		iQualityFrames[slot] = iQuality
	else
		local r, g, b = fetchQuality(slot)
		iQuality:SetBackdropBorderColor(r, g, b, 1.0)
	end
	
	iQuality:Show()
end

function makeDurability(frame, slot)
	local iDura = iDuraFrames[slot]
	if not iDura then
		iDura = CreateFrame("Frame", nil, frame)
		
		if frame == CharacterHeadSlot or frame == CharacterNeckSlot or frame == CharacterShoulderSlot or frame == CharacterBackSlot or frame == CharacterChestSlot or frame == CharacterWristSlot or frame == CharacterShirtSlot or frame == CharacterTabardSlot then
			iDura:SetPoint("BOTTOM", frame, "BOTTOM", 42, 0)
		elseif frame == CharacterHandsSlot or frame == CharacterWaistSlot or frame == CharacterLegsSlot or frame == CharacterFeetSlot or frame == CharacterFinger0Slot or frame == CharacterFinger1Slot or frame == CharacterTrinket0Slot or frame == CharacterTrinket1Slot then
			iDura:SetPoint("BOTTOM", frame, "BOTTOM", -42, 0)
		elseif frame == CharacterMainHandSlot or frame == CharacterSecondaryHandSlot or frame == CharacterRangedSlot then
			iDura:SetPoint("BOTTOM", frame, "BOTTOM", 0, 42)
		end
		
		iDura:SetSize(10,10)
		iDura:SetBackdrop({bgFile = nil, edgeFile = nil, tile = false, tileSize = 32, edgeSize = 0, insets = {left = 0, right = 0, top = 0, bottom = 0}})
		iDura:SetBackdropColor(0,0,0,0)
		
		local iDuraText = iDura:CreateFontString(nil, "ARTWORK")
		isValid = iDuraText:SetFont("Fonts\\FRIZQT__.TTF", 10)
		iDuraText:SetPoint("CENTER", iDura, "CENTER", 0, 0)
		iDura.text = iDuraText
		
		itemDurability, itemMaxDurability = fetchDura(slot)
		if itemDurability then
			local itemDurabilityPercentage = (itemDurability / itemMaxDurability) * 100
			if itemDurabilityPercentage > 25 then
				iDura.text:SetFormattedText("|cFF00FF00%i%%", itemDurabilityPercentage)
			elseif itemDurabilityPercentage > 0 and itemDurabilityPercentage <= 25 then
				iDura.text:SetFormattedText("|cFFFFFF00%i%%", itemDurabilityPercentage)
			elseif itemDurabilityPercentage == 0 then
				iDura.text:SetFormattedText("|cFFFF0000%i%%", itemDurabilityPercentage)
			end
		else
			iDura.text:SetFormattedText("")
		end
		iDuraFrames[slot] = iDura
	else
		itemDurability, itemMaxDurability = fetchDura(slot)
		if itemDurability then
			local itemDurabilityPercentage = (itemDurability / itemMaxDurability) * 100
			if itemDurabilityPercentage > 25 then
				iDura.text:SetFormattedText("|cFF00FF00%i%%", itemDurabilityPercentage)
			elseif itemDurabilityPercentage > 0 and itemDurabilityPercentage <= 25 then
				iDura.text:SetFormattedText("|cFFFFFF00%i%%", itemDurabilityPercentage)
			elseif itemDurabilityPercentage == 0 then
				iDura.text:SetFormattedText("|cFFFF0000%i%%", itemDurabilityPercentage)
			end
		else
			iDura.text:SetFormattedText("")
		end
		
		iDuraFrames[slot] = iDura
	end
	
	iDura:Show()
end

iLvLrMain()